/*
 * Copyright 2011-2012 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

public class Nuvola.Service: GLib.Object
{
	/**
	 * Prefix used for service configuration options.
	 */
	public static const string CONFIG_PREFIX = "service";
	
	[Description(nick = "service identifier", blurb = "Unique identitier of service")]
	public string id {get; construct;}
	
	[Description(nick = "name", blurb = "Name of the service")]
	public string name {get; construct;}
	
	[Description(nick = "major version", blurb = "Major version of service integration")]
	public int version {get; construct;}
	
	[Description(nick = "minor version", blurb = "Minor version of service integration")]
	public int version_minor {get; construct;}
	
	[Description(nick = "maintainer name", blurb = "Name of the maintainer")]
	public string maintainer_name {get; construct;}
	
	[Description(nick = "maintainer link", blurb = "Link to the maintainer")]
	public string maintainer_link {get; construct;}
	
	[Description(nick = "Resources URI", blurb = "URI of a directory with service resources")]
	public File resources {get; construct;}
	
	[Description(nick = "Configuration directory URI", blurb = "URI of a directory for service configuration files")]
	public File config_dir {get; construct;}
	
	[Description(nick = "Major API version", blurb = "Minimal required major API version")]
	public int api_major {get; construct;}
	
	[Description(nick = "Minor API version", blurb = "Minimal required minor API version")]
	public int api_minor {get; construct;}
	
	[Description(nick = "Home page", blurb = "Main page of the web interface")]
	public string home_page {get; construct;}
	
	[Description(nick = "Flash plugin", blurb = "Whether Flash plugin has to be enabled")]
	public bool flash_plugin {get; construct;}
	
	[Description(nick = "Playback requirements specified", blurb = "Whether playback requirements are specified in service's description")]
	public bool requirements_specified {get; construct;}
	
	[Description(nick = "Removable", blurb = "Whether the service can be removed")]
	public bool removable {get; construct;}
	
	[Description(nick = "URL sandbox", blurb = "pages not matching this regular expression will be opened in the default web browser")]
	public Regex sandbox {private get; construct;}
	
	/**
	 * Decide whether given URI is allowed in sandbox.
	 * 
	 * @param uri	URI to check
	 * @return		true if UIR matches sandbox
	 */
	public bool matches_sandbox(string uri){
		return sandbox.match(uri);
	}
}
