/*
 * Copyright 2012 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

namespace Nuvola
{

/**
 * Service selector dialog is used as a parent widget for Service selector
 * view. When the dialog is closed, Cancel action of Service selector view
 * is called.
 */
public class ServiceSelectorDialog: Gtk.Window
{
	public ServicesManagerView view {get; private set;}
	
	/**
	 * Creates new Service selector dialog
	 */
	public ServiceSelectorDialog(Diorite.Application app, ServicesManagerView view)
	{
		Object(window_position: Gtk.WindowPosition.CENTER);
		set_default_size(650, 450);
		/// Title of service selector window, %s will be replaced by application name
		title = _("Select service - %s").printf(app.display_name);
		try
		{
			icon = Gtk.IconTheme.get_default().load_icon(app.icon, 48, 0);
		}
		catch(Error e)
		{
			warning("Unable to load application icon.");
		}
		this.view = view;
		add(view);
	}
	
	public override bool delete_event(Gdk.EventAny event){
		view.response(Gtk.ResponseType.CANCEL);
		return true;
	}
}

} // namespace Nuvola
